/*

FLARToolkit example in Away3d

Demonstrates:

How to setup the FLARToolkit with the Away3d engine.
How to define trackable objects with FLARBaseNode
How to reset the camera source in actionscript

code by Rob Bateman
rob@infiniteturtles.co.uk
http://www.infiniteturtles.co.uk

This code is distributed under the MIT License

Copyright (c)  

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the “Software”), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

*/

package
{
	import com.adobe.viewsource.ViewSource;
	
	import flash.events.*;
	import flash.filters.*;
	import flash.media.*;
	
	import mx.containers.*;
	import mx.controls.*;
	import mx.core.*;
	import mx.events.*;

	public class AwayFLARDemoUI extends Application
	{
		private var colorMatrixFilter:ColorMatrixFilter = new ColorMatrixFilter([0.5, 0, 0, 0, 0, 0, 0.5, 0, 0, 0, 0, 0, 0.5, 0, 0, 0, 0, 0, 1, 0]);
		
		/**
		 * view layer
		 */
		public var awayFLARView:AwayFLARView;
		
		/**
		 * camera source combobox
		 */
		public var camCombo:ComboBox;
		
		/**
		 * close button
		 */
		public var closeButton:Button;
		
		/**
		 * camera source selector panel
		 */
		public var cameraPanel:Panel;

		/**
		 * Constructor
		 */
		public function AwayFLARDemoUI()
		{
			super();
			addEventListener( FlexEvent.CREATION_COMPLETE, creationCompleteHandler );
		}

		/**
		 * Handler for creation complete event
		 */
		public function creationCompleteHandler(event:FlexEvent):void
		{
			//add source menu
			ViewSource.addMenuItem(this, "srcview/index.html");
			
			//initialise view
			awayFLARView.initListeners();
			awayFLARView.webcam = null;
			awayFLARView.filters = [colorMatrixFilter];
			
			//initialise camera
			var camDataProvider:Array = new Array();
			var camSelection:int = 0;
			
			for each (var name:String in Camera.names) {
				if (name == awayFLARView.webcam)
					camSelection = camDataProvider.length;
				camDataProvider.push({label:name, data:name});
			}
			
			//initialise combobox
			camCombo.dataProvider = camDataProvider;
			camCombo.selectedIndex = camSelection;
			camCombo.addEventListener(Event.CHANGE, onComboChange);
			
			//initialise close button
			closeButton.addEventListener(MouseEvent.CLICK, onCloseButton);
		}

		/**
		 * Handler for combo change event
		 */
		public function onComboChange(event:Event):void
		{
			awayFLARView.webcam = camCombo.selectedLabel;
		}
		
		/**
		 * Handler for button event
		 */
		public function onCloseButton(event:MouseEvent):void
		{
			cameraPanel.visible = false;
			awayFLARView.update = true;
			awayFLARView.filters = [];
		}
	}
}